# Documentation

This directory contains the project's documentation sources. This includes:

* the handwritten documentation files,
* the configuration for an auto-generated API documentation, and
* tutorials that help to get started with the project.

_**TODO** Provide more information about the contents of this directory once it_
_is in use._
